"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "withMobx", {
  enumerable: true,
  get: function get() {
    return _withMobx.default;
  }
});
exports.getOrCreateStore = exports.BaseStore = void 0;

var _withMobx = _interopRequireDefault(require("./with-mobx"));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var __NEXT_MOBX_STORE__ = new Map();

var BaseStore = function BaseStore() {
  var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  _classCallCheck(this, BaseStore);

  for (var prop in props) {
    // Convert JSON string to Map string for client
    this[prop] = (0, _utils.jsonToMap)(props[prop]);
  }
};

exports.BaseStore = BaseStore;

var getOrCreateStore = function getOrCreateStore(storeKeyName, Store) {
  return function (initialState) {
    // Convert Map to JSON string for client
    if (initialState) {
      for (var itemState in initialState) {
        try {
          var dataMap = initialState[itemState];

          if (dataMap.toJS() instanceof Map) {
            initialState[itemState] = (0, _utils.mapToJson)(dataMap);
          }
        } catch (e) {}
      }
    } // Always make a new store if server, otherwise state is shared between requests


    if (_utils.isServer) {
      return new Store(initialState);
    } // Create store if unavailable on the client and set it on the window object


    if (!__NEXT_MOBX_STORE__.has(storeKeyName)) {
      __NEXT_MOBX_STORE__.set(storeKeyName, new Store(initialState));
    }

    return __NEXT_MOBX_STORE__.get(storeKeyName);
  };
};

exports.getOrCreateStore = getOrCreateStore;
//# sourceMappingURL=index.js.map